<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://your-style.nl
 * @since      1.0.0
 *
 * @package    Yourstyle_Plus_Companion_Plugin
 * @subpackage Yourstyle_Plus_Companion_Plugin/includes
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * @package    Yourstyle_Plus_Companion_Plugin
 * @subpackage Yourstyle_Plus_Companion_Plugin/includes
 * @author     Bjorn Manintveld <bjorn@yourstyledesign.nl>
 */

class Yourstyle_Plus_Companion_Plugin_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
    private $plugin_name;
    

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
    private $version;
    
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version           The version of this plugin.
	 */
    public function __construct($plugin_name, $version)
    {

		$this->plugin_name = $plugin_name;
        $this->version = $version;

        /* Register Admin Page: Add-ons */
        add_action('admin_menu', array($this, 'register_admin_menus'), 19);

        /* Register Options */
        add_action('admin_init', array($this, 'register_options'));
    }

    public function register_admin_menus()
    {
        // Only allow user Yourstyle
        $user = wp_get_current_user();
        $allowed_users = array('yourstyle', 'Yourstyle');
        if ( ! in_array( $user->user_login, $allowed_users ) ) {
            return;
        }

        add_submenu_page(
            'ysp-dashboard',
            __('Add-ons', 'yourstyle-plus-companion-plugin'),
            __('Add-ons', 'yourstyle-plus-companion-plugin'),
            'manage_options',
            'ysp-dashboard-addons',
            array($this, 'render_admin_addons')
        );

        add_submenu_page(
            'ysp-dashboard',
            'WPBakery',
            'WPBakery',
            'manage_options',
            'ysp-dashboard-wpbi',
            array($this, 'render_admin_wpbi')
        );
    }

    public function register_options()
    {
        /*
         * Register Options for Add-Ons
         */
        /* Duplicate Menu */
        register_setting('yourstyle-plus', 'ysp-addon-duplicate-menu');
        add_option('ysp-addon-duplicate-menu', '1');
        /* Duplicate Post */
        register_setting('yourstyle-plus', 'ysp-addon-duplicate-post');
        add_option('ysp-addon-duplicate-post', '1');
        /* Hang Nav */
        register_setting('yourstyle-plus', 'ysp-addon-hang-nav');
        add_option('ysp-addon-hang-nav', '0');
        /* SVG Upload */
        register_setting('yourstyle-plus', 'ysp-addon-svg-upload');
        add_option('ysp-addon-svg-upload', '1');
        /* Top Header */
        register_setting('yourstyle-plus', 'ysp-addon-top-header');
        add_option('ysp-addon-top-header', '0');
        /* Widget Accordion */
        register_setting('yourstyle-plus', 'ysp-addon-widget-accordion');
        add_option('ysp-addon-widget-accordion', '0');
        /* Widget CSS Classes */
        register_setting('yourstyle-plus', 'ysp-addon-widget-css-classes');
        add_option('ysp-addon-widget-css-classes', '1');
        /* Widget Shortcode */
        register_setting('yourstyle-plus', 'ysp-addon-widget-shortcode');
        add_option('ysp-addon-widget-shortcode', '1');
        /* Mediabox Shortcode */
        register_setting('yourstyle-plus', 'ysp-addon-mediabox-shortcode');
        add_option('ysp-addon-mediabox-shortcode', '1');
    }

    public function render_admin_addons()
    {
        $addons = array(
            'admin-column-ids' => array(
                'name' => __('Admin Column IDs', 'yourstyle-plus-companion-plugin'),
                'description' => __('Show Post IDs on Media, Pages and Posts', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-admin-column-ids',
            ),
            'duplicate-menu' => array(
                'name' => __('Duplicate Menu', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to easily duplicate menus.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-duplicate-menu',
            ),
            'duplicate-post' => array(
                'name' => __('Duplicate Post', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to easily duplicate posts and pages.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-duplicate-post',
            ),
            'hang-nav' => array(
                'name' => __('Hanging Navigation', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to create a hanging navigation.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-hang-nav',
            ),
            'svg-upload' => array(
                'name' => __('SVG Upload', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to upload SVG files in your Media Library.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-svg-upload',
            ),
            'top-header' => array(
                'name' => __('Top Header', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to create a top header with widgets.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-top-header',
            ),
            'widget-accordion' => array(
                'name' => __('Widget Accordion', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds a component with the ability to add a widget with accordion functionalities.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-widget-accordion',
            ),
            'widget-css-classes' => array(
                'name' => __('Widget CSS Classes', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to add CSS classes to your widgets directly from the widget areas.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-widget-css-classes',
            ),
            'widget-shortcode' => array(
                'name' => __('Widget Shortcode', 'yourstyle-plus-companion-plugin'),
                'description' => __('Adds the ability to output widgets using a simple shortcode.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-widget-shortcode',
            ),
            'mediabox-shortcode' => array(
                'name' => __('Mediabox Shortcode', 'yourstyle-plus-companion-plugin'),
                'description' => __('Enables the Mediabox Shortcode and Component.', 'yourstyle-plus-companion-plugin'),
                'option' => 'ysp-addon-mediabox-shortcode',
            ),            
        );
        require_once plugin_dir_path(dirname( __FILE__ )) . 'admin/views/admin-addons.php';
    }

    public function render_admin_wpbi()
    {
        $vcis = array(
            'vc_custom_heading' => array(
                'name' => 'Custom Heading',
                'description' => '',
                'option' => 'vc_custom_heading',
            ),
            'vc_empty_space' => array(
                'name' => 'Empty Space',
                'description' => '',
                'option' => 'vc_empty_space',
            ),
            'vc_flickr' => array(
                'name' => 'Flickr',
                'description' => '',
                'option' => 'vc_flickr',
            ),
            'vc_gallery' => array(
                'name' => 'Gallery',
                'description' => '',
                'option' => 'vc_gallery',
            ),
            'vc_gmaps' => array(
                'name' => 'GMaps',
                'description' => '',
                'option' => 'vc_gmaps',
            ),
            'vc_icon' => array(
                'name' => 'Icon',
                'description' => '',
                'option' => 'vc_icon',
            ),
            'vc_images_carousel' => array(
                'name' => 'Images Carousel',
                'description' => '',
                'option' => 'vc_images_carousel',
            ),
            'vc_line_chart' => array(
                'name' => 'Line Chart',
                'description' => '',
                'option' => 'vc_line_chart',
            ),
            'vc_message' => array(
                'name' => 'Message',
                'description' => '',
                'option' => 'vc_message',
            ),
            'vc_pie' => array(
                'name' => 'PIE',
                'description' => '',
                'option' => 'vc_pie',
            ),
            'vc_posts_slider' => array(
                'name' => 'Posts Slider',
                'description' => '',
                'option' => 'vc_posts_slider',
            ),
            'vc_progress_bar' => array(
                'name' => 'Progress Bar',
                'description' => '',
                'option' => 'vc_progress_bar',
            ),
            'vc_round_chart' => array(
                'name' => 'Round Chart',
                'description' => '',
                'option' => 'vc_round_chart',
            ),
            'vc_separator' => array(
                'name' => 'Separator',
                'description' => '',
                'option' => 'vc_separator',
            ),
            'vc_single_image' => array(
                'name' => 'Single Image',
                'description' => '',
                'option' => 'vc_single_image',
            ),
            'vc_text_separator' => array(
                'name' => 'Text Separator',
                'description' => '',
                'option' => 'vc_text_separator',
            ),
            'vc_toggle' => array(
                'name' => 'Toggle',
                'description' => '',
                'option' => 'vc_toggle',
            ),
            'vc_icon_element' => array(
                'name' => 'Icon Element',
                'description' => '',
                'option' => 'vc_icon_element',
            ),
            'vc_btn' => array(
                'name' => 'BTN',
                'description' => '',
                'option' => 'vc_btn',
            ),
            'vc_cta' => array(
                'name' => 'CTA',
                'description' => '',
                'option' => 'vc_cta',
            ),
            'vc_section' => array(
                'name' => 'Section',
                'description' => '',
                'option' => 'vc_section',
            ),
            'vc_hoverbox' => array(
                'name' => 'Hoverbox',
                'description' => '',
                'option' => 'vc_hoverbox',
            ),
            'vc_zigzag' => array(
                'name' => 'ZigZag',
                'description' => '',
                'option' => 'vc_zigzag',
            ),
            'vc_widget_sidebar' => array(
                'name' => 'Widget Sidebar',
                'description' => '',
                'option' => 'vc_widget_sidebar',
            ),
            'vc_raw_js' => array(
                'name' => 'Raw JS',
                'description' => '',
                'option' => 'vc_raw_js',
            ),
            'vc_facebook' => array(
                'name' => 'Facebook',
                'description' => '',
                'option' => 'vc_facebook',
            ),
            'vc_googleplus' => array(
                'name' => 'GooglePlus',
                'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
                'option' => 'vc_googleplus',
            ),
            'vc_pinterest' => array(
                'name' => 'Pinterest',
                'description' => '',
                'option' => 'vc_pinterest',
            ),
            'vc_tweetmeme' => array(
                'name' => 'Tweetmeme',
                'description' => '',
                'option' => 'vc_tweetmeme',
            ),
            'vc_grids_common' => array(
                'name' => 'Grids Common',
                'description' => '',
                'option' => 'vc_grids_common',
            ),
            'vc_basic_grid' => array(
                'name' => 'Basic Grid',
                'description' => '',
                'option' => 'vc_basic_grid',
            ),
            'vc_masonry_grid' => array(
                'name' => 'Masonry Grid',
                'description' => '',
                'option' => 'vc_masonry_grid',
            ),
            'vc_masonry_media_grid' => array(
                'name' => 'Masonry Media Grid',
                'description' => '',
                'option' => 'vc_masonry_media_grid',
            ),
            'vc_media_grid' => array(
                'name' => 'Media Grid',
                'description' => '',
                'option' => 'vc_media_grid',
            ),
            'vc_tta_accordion' => array(
                'name' => 'TTA Accordion',
                'description' => '',
                'option' => 'vc_tta_accordion',
            ),
            'vc_tta_pageable' => array(
                'name' => 'TTA Pageable',
                'description' => '',
                'option' => 'vc_tta_pageable',
            ),
            'vc_tta_section' => array(
                'name' => 'TTA Section',
                'description' => '',
                'option' => 'vc_tta_section',
            ),
            'vc_tta_tabs' => array(
                'name' => 'TTA Tabs',
                'description' => '',
                'option' => 'vc_tta_tabs',
            ),
            'vc_tta_tour' => array(
                'name' => 'TTA Tour',
                'description' => '',
                'option' => 'vc_tta_tour',
            ),
            'vc_tabs' => array(
                'name' => 'Tabs',
                'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
                'option' => 'vc_tabs',
            ),
            'vc_tour' => array(
                'name' => 'Tour',
                'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
                'option' => 'vc_tour',
            ),
            'vc_tab' => array(
                'name' => 'Tab',
                'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
                'option' => 'vc_tab',
            ),
            'vc_accordion' => array(
                'name' => 'Accordion',
                'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
                'option' => 'vc_accordion',
            ),
            'vc_accordion_tab' => array(
                'name' => 'Accordion Tab',
                'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
                'option' => 'vc_accordion_tab',
            ),
            'vc_posts_grid' => array(
                'name' => 'Posts Grid',
                'description' => '',
                'option' => 'vc_posts_grid',
            ),
            'vc_carousel' => array(
                'name' => 'Carousel',
                'description' => '',
                'option' => 'vc_carousel',
            ),
            'vc_button' => array(
                'name' => 'Button',
                'description' => '',
                'option' => 'vc_button',
            ),
            'vc_button2' => array(
                'name' => 'Button2',
                'description' => '',
                'option' => 'vc_button2',
            ),
            'vc_cta_button' => array(
                'name' => 'CTA Button',
                'description' => '',
                'option' => 'vc_cta_button',
            ),
            'vc_cta_button2' => array(
                'name' => 'CTA Button2',
                'description' => '',
                'option' => 'vc_cta_button2',
            ),
            'vc_wp_archives' => array(
                'name' => 'WP Archives',
                'description' => '',
                'option' => 'vc_wp_archives',
            ),
            'vc_wp_categories' => array(
                'name' => 'WP Categories',
                'description' => '',
                'option' => 'vc_wp_categories',
            ),
            'vc_wp_calendar' => array(
                'name' => 'WP Calendar',
                'description' => '',
                'option' => 'vc_wp_calendar',
            ),
            'vc_wp_custommenu' => array(
                'name' => 'WP Custom Menu',
                'description' => '',
                'option' => 'vc_wp_custommenu',
            ),
            'vc_wp_links' => array(
                'name' => 'WP Links',
                'description' => '',
                'option' => 'vc_wp_links',
            ),
            'vc_wp_meta' => array(
                'name' => 'WP Meta',
                'description' => '',
                'option' => 'vc_wp_meta',
            ),
            'vc_wp_pages' => array(
                'name' => 'WP Pages',
                'description' => '',
                'option' => 'vc_wp_pages',
            ),
            'vc_wp_posts' => array(
                'name' => 'WP Posts',
                'description' => '',
                'option' => 'vc_wp_posts',
            ),
            'vc_wp_recentcomments' => array(
                'name' => 'WP Recent Comments',
                'description' => '',
                'option' => 'vc_wp_recentcomments',
            ),
            'vc_wp_rss' => array(
                'name' => 'WP RSS',
                'description' => '',
                'option' => 'vc_wp_rss',
            ),
            'vc_wp_search' => array(
                'name' => 'WP Search',
                'description' => '',
                'option' => 'vc_wp_search',
            ),
            'vc_wp_tagcloud' => array(
                'name' => 'WP Tag Cloud',
                'description' => '',
                'option' => 'vc_wp_tagcloud',
            ),
            'vc_wp_text' => array(
                'name' => 'WP Text',
                'description' => '',
                'option' => 'vc_wp_text',
            ),
        );
        require_once plugin_dir_path(dirname( __FILE__ )) . 'admin/views/admin-vc-integration.php';
    }

}