<?php
/**
 * yourstyle+ Duplicate Post
 * Based on Duplicate Post Wordpress Plugin by Enrico Battoccohi
 *
 * @package     Yourstyle_Plus_Companion_Plugin
 * @subpackage  Yourstyle_Plus_Companion_Plugin/addons
 * @since       1.0.0
 * @author      Bjorn Manintveld
 * @link        https://wordpress.org/plugins/duplicate-post/
 * @version     1.0.0
 */

if (!class_exists('ysdb_duplicate_post')) {

    class ysdb_duplicate_post
    {
	
        function __construct()
        {
			// Add Duplicate links to Wordpress posts/pages table
			add_filter('post_row_actions', array($this,'duplicate_link_post_row'),10,2);
			add_filter('page_row_actions', array($this,'duplicate_link_post_row'),10,2);
			
			// Add a button to post/page edit screen
			add_action('post_submitbox_misc_actions', array($this, 'duplicate_link_post_edit'));
			
			// Save Post as New Post
			add_action('admin_action_duplicate_post_save_as_new_post', array($this,'save_post_as_new_post'));
			add_action('admin_action_duplicate_post_save_as_new_post_draft', array($this,'save_post_as_new_post_draft'));
			
			// Copy Taxonomies to the duplicated post
			add_action('dp_duplicate_post', array($this,'copy_taxonomies'), 10, 2);
			add_action('dp_duplicate_page', array($this,'copy_taxonomies'), 10, 2);
			
			// Copy Meta Fields to the duplicated post
			add_action('dp_duplicate_post', array($this,'copy_metafields'), 10, 2);
			add_action('dp_duplicate_page', array($this,'copy_metafields'), 10, 2);
			
			// Copy Attachments to the duplicated post
			add_action('dp_duplicate_post', array($this,'copy_attachments'), 10, 2);
			add_action('dp_duplicate_page', array($this,'copy_attachments'), 10, 2);
		}
		
		// Add Duplicate links to Wordpress posts/pages table
        function duplicate_link_post_row($actions, $post)
        {
			if (current_user_can('edit_posts')) {
				$actions['clone'] = '<a href="'.$this->get_clone_post_link( $post->ID,'display', false).'" title="'.esc_attr(__("Clone this item", 'yourstyle-plus-companion-plugin')).'">'.__('Clone', 'yourstyle-plus-companion-plugin').'</a>';
				$actions['edit_as_new_draft'] = '<a href="'. $this->get_clone_post_link( $post->ID ).'" title="'.esc_attr(__('Copy to a new draft', 'yourstyle-plus-companion-plugin')).'">'.__('New Draft', 'yourstyle-plus-companion-plugin').'</a>';
			}
			return $actions;
		}
		
		// Add a button to post/page edit screen
        function duplicate_link_post_edit()
        {
			if (isset($_GET['post']) && current_user_can('edit_posts')) {
				?>
				<div class="misc-pub-section" style="overflow:hidden;">
					<a class="submitduplicate duplication button" href="<?php echo $this->get_clone_post_link( $_GET['post'] ) ?>"><?php _e('Make copy', 'yourstyle-plus-companion-plugin'); ?></a>
				</div>
				<?php
			}
		}
		
		// Save Post as New Post
        function save_post_as_new_post_draft()
        {
			$this->save_post_as_new_post('draft');
		}
		
        function save_post_as_new_post($status = '')
        {
			if (!(isset($_GET['post']) || isset($_POST['post'])  || (isset($_REQUEST['action']) && 'save_post_as_new_post' == $_REQUEST['action']))) {
				wp_die(__('No post to duplicate has been supplied!', 'yourstyle-plus-companion-plugin'));
			}

			// Get the original post
			$id = (isset($_GET['post']) ? $_GET['post'] : $_POST['post']);
			$post = get_post($id);

			// Copy the post and insert it
			if (isset($post) && $post!=null) {
				$new_id = $this->duplicate($post, $status);

				if ($status == ''){
					// Redirect to the post list screen
					wp_redirect(admin_url('edit.php?post_type='.$post->post_type));
				} else {
					// Redirect to the edit screen for the new draft post
					wp_redirect(admin_url('post.php?action=edit&post=' . $new_id ));
				}
				exit;
			} else {
				$post_type_obj = get_post_type_object($post->post_type);
				wp_die(esc_attr(__('Copy creation failed, could not find original:', 'yourstyle-plus-companion-plugin')) . ' ' . htmlspecialchars($id));
			}
		}
		
		// Get current user
        function current_post_user()
        {
			if (function_exists('wp_get_current_user')) {
				return wp_get_current_user();
			} else if (function_exists('get_currentuserinfo')) {
				global $userdata;
				get_currentuserinfo();
				return $userdata;
			} else {
				$user_login = $_COOKIE[USER_COOKIE];
				$sql = $wpdb->prepare("SELECT * FROM $wpdb->users WHERE user_login=%s", $user_login);
				$current_user = $wpdb->get_results($sql);			
				return $current_user;
			}
		}
		
		// Copy Taxonomies to the duplicated post
        function copy_taxonomies($new_id, $post)
        {
			global $wpdb;
			if (isset($wpdb->terms)) {
				// Clear default category (added by wp_insert_post)
				wp_set_object_terms($new_id, NULL, 'category');

				$post_taxonomies = get_object_taxonomies($post->post_type);
				$taxonomies_blacklist = "";
				if ($taxonomies_blacklist == "") $taxonomies_blacklist = array();
				$taxonomies = array_diff($post_taxonomies, $taxonomies_blacklist);
				foreach ($taxonomies as $taxonomy) {
					$post_terms = wp_get_object_terms($post->ID, $taxonomy, array('orderby' => 'term_order'));
					$terms = array();
					for ($i=0; $i<count($post_terms); $i++) {
						$terms[] = $post_terms[$i]->slug;
					}
					wp_set_object_terms($new_id, $terms, $taxonomy);
				}
			}
		}
		
		// Copy Meta Fields to the duplicated post
        function copy_metafields($new_id, $post)
        {
			$post_meta_keys = get_post_custom_keys($post->ID);
			if (empty($post_meta_keys)) return;
			$meta_blacklist = "";
			if ($meta_blacklist == "") $meta_blacklist = array();
			$meta_keys = array_diff($post_meta_keys, $meta_blacklist);

			foreach ($meta_keys as $meta_key) {
				$meta_values = get_post_custom_values($meta_key, $post->ID);
				foreach ($meta_values as $meta_value) {
					$meta_value = maybe_unserialize($meta_value);
					add_post_meta($new_id, $meta_key, $meta_value);
				}
			}
		}
		
		// Copy Attachments to the duplicated post
        function copy_attachments($new_id, $post)
        {
			// get children
			$children = get_posts(array('post_type' => 'any', 'numberposts' => -1, 'post_status' => 'any', 'post_parent' => $post->ID));
			// clone old attachments
			foreach($children as $child) {
				if ($child->post_type == 'attachment') continue;
				if ($child->post_type != 'attachment') continue;
				$this->duplicate($child, '', $new_id);
			}
		}
		
		// Duplicate Post
        function duplicate($post, $status = '', $parent_id = '')
        {
			// We don't want to clone revisions
			if ($post->post_type == 'revision') {
                return;
            }

			if ($post->post_type != 'attachment') {
				$prefix = "";
				$suffix = "";
				if (!empty($prefix)) $prefix.= " ";
				if (!empty($suffix)) $suffix = " ".$suffix;
				$status = 'draft';
			}
			$new_post_author = $this->current_post_user();

			$new_post = array(
			'menu_order' => $post->menu_order,
			'comment_status' => $post->comment_status,
			'ping_status' => $post->ping_status,
			'post_author' => $new_post_author->ID,
			'post_content' => $post->post_content,
			'post_excerpt' => $post->post_excerpt,
			'post_mime_type' => $post->post_mime_type,
			'post_parent' => $new_post_parent = empty($parent_id)? $post->post_parent : $parent_id,
			'post_password' => $post->post_password,
			'post_status' => $new_post_status = (empty($status))? $post->post_status: $status,
			'post_title' => $prefix.$post->post_title.$suffix,
			'post_type' => $post->post_type,
			'post_date' => $new_post_date = $post->post_date,
			'post_date_gmt' => get_gmt_from_date($new_post_date),
			);

			$new_post_id = wp_insert_post($new_post);

			// If the copy is published or scheduled, we have to set a proper slug.
			if ($new_post_status == 'publish' || $new_post_status == 'future') {
				$post_name = wp_unique_post_slug($post->post_name, $new_post_id, $new_post_status, $post->post_type, $new_post_parent);

				$new_post = array();
				$new_post['ID'] = $new_post_id;
				$new_post['post_name'] = $post_name;

				// Update the post into the database
				wp_update_post($new_post);
			}

			// If you have written a plugin which uses non-WP database tables to save
			// information about a post you can hook this action to dupe that data.
			if ($post->post_type == 'page' || (function_exists('is_post_type_hierarchical') && is_post_type_hierarchical( $post->post_type ))) {
                do_action( 'dp_duplicate_page', $new_post_id, $post );
            } else {
                do_action( 'dp_duplicate_post', $new_post_id, $post );
            }

			delete_post_meta($new_post_id, '_dp_original');
			add_post_meta($new_post_id, '_dp_original', $post->ID);

			return $new_post_id;
		}
		
		// Get the duplicate post link for post
		function get_clone_post_link($id = 0, $context = 'display', $draft = true) {
			if (!current_user_can('edit_posts')) {
                return;
            }			

			if (!$post = get_post($id)) {
                return;
            }

			if ($draft) {
                $action_name = "duplicate_post_save_as_new_post_draft";
            } else {
                $action_name = "duplicate_post_save_as_new_post";
            }

			if ('display' == $context) {
                $action = '?action='.$action_name.'&amp;post='.$post->ID;
            } else {
                $action = '?action='.$action_name.'&post='.$post->ID;
            }

			$post_type_object = get_post_type_object($post->post_type);
			if (!$post_type_object) {
                return;
            }

			return apply_filters('get_clone_post_link', admin_url("admin.php". $action), $post->ID, $context);
		}
		
		// Display duplicate post link for post
        function clone_post_link($link = null, $before = '', $after = '', $id = 0)
        {
			if (!$post = get_post($id)) {
                return;
            }

			if (!$url = $this->get_clone_post_link($post->ID)) {
                return;
            }			

			if (null === $link) {
                $link = __('Copy to a new draft', 'yourstyle-plus-companion-plugin');
            }

			$post_type_obj = get_post_type_object($post->post_type);
			$link = '<a class="post-clone-link" href="' . $url . '" title="'
			. esc_attr(__("Copy to a new draft", 'yourstyle-plus-companion-plugin'))
			.'">' . $link . '</a>';
			echo $before . apply_filters('clone_post_link', $link, $post->ID ) . $after;
		}
		
		// Get original post
		function get_original_post($id = 0 , $output = OBJECT) {
			if (!$post = get_post($id)) {
                return;
            }
			$original_ID = get_post_meta($post->ID, '_dp_original');
			if (empty($original_ID)) {
                return null;
            }
			$original_post = get_post($original_ID[0],  $output);
			return $original_post;
		}

	}
	
	if (is_admin()) {
		new ysdb_duplicate_post();
	}

}