<?php
/**
 * Yourstyle+ Top Header
 * 
 * Adds the ability to create a top header with widgets
 *
 * @package     Yourstyle_Plus_Companion_Plugin
 * @subpackage  Yourstyle_Plus_Companion_Plugin/addons
 * @since       1.0.0
 * @author      Thomas Bulten
 * @link        https://your-style.nl/
 * @version     1.0.0
 */

if (!class_exists('ysp_top_header'))
{
    
    class ysp_top_header
    {

        function __construct()
        {
            
            // Top Header Widgets
            add_action('widgets_init', array($this, 'ysp_top_header_widgets'));

            // Top Header Layout
            add_action('ysp_before_header_inner', array($this, 'ysp_top_header_layout'));
            
            // Add Top Header Sidebar Left
            if (!function_exists('ysp_top_header_left_sidebar')) {
                add_action('ysp_top_header', array($this, 'ysp_top_header_left_sidebar'), 10);
            }

            // Add Top Header Sidebar Right
            if (!function_exists('ysp_top_header_right_sidebar')) {
                add_action('ysp_top_header', array($this, 'ysp_top_header_right_sidebar'), 20);
            }
        }

        function ysp_top_header_widgets()
        {
            
            // Register widget area: Top Header: Left
            register_sidebar(array(
                'name'          =>  esc_html__('Top Header: Left', 'yourstyle-plus-companion-plugin'),
                'id'            =>  'top-header-left',
                'description'   =>  esc_html__('These widgets will be displayed at the left side of your top header.', 'yourstyle-plus-companion-plugin'),
                'before_widget' =>  '<section id="%1$s" class="c-widget u-mb-0 %2$s">',
                'after_widget'  =>  '</section>',
                'before_title'  =>  '<h6 class="c-widget-title u-h3">',
                'after_title'   =>  '</h6>',
            ));
            
            // Register widget area: Top Header: Right
            register_sidebar(array(
                'name'          =>  esc_html__('Top Header: Right', 'yourstyle-plus-companion-plugin'),
                'id'            =>  'top-header-right',
                'description'   =>  esc_html__('These widgets will be displayed at the right side of your top header.', 'yourstyle-plus-companion-plugin'),
                'before_widget' =>  '<section id="%1$s" class="c-widget u-mb-0 %2$s">',
                'after_widget'  =>  '</section>',
                'before_title'  =>  '<h6 class="c-widget-title u-h3">',
                'after_title'   =>  '</h6>',
            ));
        }

        function ysp_top_header_layout()
        {
            if (! is_active_sidebar('top-header-left') && ! is_active_sidebar('top-header-right')) {
                return;
            }
            ?>
                <div class="site-header-top">
                    <div class="c-container">
                        <div class="c-row u-align-items-center">
                            <?php do_action('ysp_top_header'); ?>
                        </div>
                    </div>
                </div>
            <?php
        }

        function ysp_top_header_left_sidebar()
        {
            if (is_active_sidebar('top-header-left')) {
                echo '<div class="c-col">';
                    dynamic_sidebar('top-header-left');
                echo '</div>';
            }
        }

    
        function ysp_top_header_right_sidebar()
        {
            if (is_active_sidebar('top-header-right')) {
                echo '<div class="c-col u-text-right">';
                    dynamic_sidebar('top-header-right');
                echo '</div>';
            }
        }

    }

}

new ysp_top_header();