<?php
/**
 * Yourstyle+ Widget CSS Classes
 * 
 * Adds the ability to add CSS classes to widgets
 *
 * @package     Yourstyle_Plus_Companion_Plugin
 * @subpackage  Yourstyle_Plus_Companion_Plugin/addons
 * @since       1.0.0
 * @author      Bjorn Manintveld
 * @link        https://your-style.nl/
 * @version     1.0.0
 */

if (!class_exists('ysp_widget_css_classes'))
{
    
    class ysp_widget_css_classes
    {

        function __construct()
        {
            add_action('in_widget_form', array($this, 'extend_widget_form'), 5, 3);
            add_filter('widget_update_callback', array($this, 'save_extended_form'), 5, 3);
            add_filter('dynamic_sidebar_params', array($this, 'add_classes_to_widgets'));
        }
        
        function extend_widget_form($t,$return,$instance)
        {
            $instance = wp_parse_args((array) $instance, array('title' => '', 'text' => ''));
            if (!isset($instance['ysp_widget_css_class'])) {
                $instance['ysp_widget_css_class'] = null;
            }
            ?>
            <p>
                <label for="<?php echo $t->get_field_name('ysp_widget_css_class'); ?>">
                    <?php _e('CSS Class', 'yourstyle-plus-companion-plugin'); ?>:
                    <input type="text" class="widefat" name="<?php echo $t->get_field_name('ysp_widget_css_class'); ?>" id="<?php echo $t->get_field_id('ysp_widget_css_class'); ?>" value="<?php echo $instance['ysp_widget_css_class'];?>" />
                </label>
            </p>
            <?php
            $return = null;
            return array($t,$return,$instance);
        }

        function save_extended_form($instance, $new_instance, $old_instance)
        {
            $instance['ysp_widget_css_class'] = strip_tags($new_instance['ysp_widget_css_class']);
            return $instance;
        }

        function add_classes_to_widgets($params)
        {
            global $wp_registered_widgets;
            $widget_id = $params[0]['widget_id'];
            $widget_obj = $wp_registered_widgets[$widget_id];
            $widget_opt = get_option($widget_obj['callback'][0]->option_name);
            $widget_num = $widget_obj['params'][0]['number'];
            if (isset($widget_opt[$widget_num]['ysp_widget_css_class']) && !empty($widget_opt[$widget_num]['ysp_widget_css_class'])) {
                $classes = $widget_opt[$widget_num]['ysp_widget_css_class'];
            } else {
                $classes = '';
            }
            if (!empty($classes)) {
                $params[0]['before_widget'] = preg_replace('/class="/', 'class="'.$classes.' ',  $params[0]['before_widget'], 1);
            }
            return $params;
        }

    }

}

new ysp_widget_css_classes();