const path = require("path");
const webpack = require("webpack");
//https://dev.to/pixelgoo/how-to-configure-webpack-from-scratch-for-a-basic-website-46a5
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const FileManagerPlugin = require("filemanager-webpack-plugin");

module.exports = [{
    name: "addon-widget-accordion",
    // Path to your entry point. From this file Webpack will begin his work
    entry: [
        "./public/assets/src/js/addon-widget-accordion.js",
        "./public/assets/src/scss/addon-widget-accordion.scss"
    ],
    output: {
        path: path.resolve(__dirname, "public/assets/dist"),
        filename: "js/addon-widget-accordion.min.js",
        publicPath: "../"
    },
    module: {
        rules: [{
            // Apply rule for .sass, .scss or .css files
            test: /\.(sa|sc|c)ss$/,
            // Set loaders to transform files.
            // Loaders are applying from right to left(!)
            // The first loader will be applied after others
            use: [{
                    // After all CSS loaders we use plugin to do his work.
                    // It gets all transformed CSS and extracts it into separate
                    // single bundled file
                    loader: MiniCssExtractPlugin.loader
                },
                {
                    // This loader resolves url() and @imports inside CSS
                    loader: "css-loader"
                },
                {
                    // Then we apply postCSS fixes like autoprefixer and minifying
                    loader: "postcss-loader"
                },
                {
                    // First we transform SASS to standard CSS
                    loader: "sass-loader",
                    options: {
                        implementation: require("sass")
                    }
                }
            ]
        }]
    },
    plugins: [
        new MiniCssExtractPlugin({
            filename: "css/addon-widget-accordion.min.css"
        })
    ]
}];